Learn R Programming

intansv (version 1.10.0)

readCnvnator: Read in the structural variations predicted by CNVnator

Description

Reading the structural variations predicted by CNVnator, filtering low quality predictions and merging overlapping predictions.

Usage

readCnvnator(dataDir=".", regSizeLowerCutoff=100, regSizeUpperCutoff=1000000, method="CNVnator")

Arguments

dataDir
the directory that contain the output files of CNVnator.
regSizeLowerCutoff
the minimum size for a structural variation to be read.
regSizeUpperCutoff
the maximum size for a structural variation to be read.
method
a tag to assign to the result of this function.

Value

A list with the following components:
del
the deletions predicted by CNVnator.
dup
the duplications predicted by CNVnator.

Details

The predicted SVs could be further filtered by the predicted size of SVs to get more reliable SVs. See our paper for more details. The directory that specified by the parameter "dataDir" should only contain the predictions of CNVnator. See the example dataset for more details.

Examples

Run this code

    cnvnator <- readCnvnator(system.file("extdata/cnvnator",package="intansv"))
    str(cnvnator)

Run the code above in your browser using DataLab