Learn R Programming

intansv (version 1.10.0)

readPindel: Read in the structural variations predicted by Pindel

Description

Reading the structural variations predicted by Pindel, filtering low quality predictions and merging overlapping predictions.

Usage

readPindel(dataDir=".", regSizeLowerCutoff=100, regSizeUpperCutoff=1000000, readsSupport=3, method="Pindel")

Arguments

dataDir
the directory containing the prediction results of Pindel.
regSizeLowerCutoff
the minimum size for a structural variation to be read.
regSizeUpperCutoff
the maximum size for a structural variation to be read.
readsSupport
the minimum read pair support for a structural variation to be read.
method
a tag to assign to the result of this function.

Value

A list with the following components:
del
the deletions predicted by Pindel.
dup
the duplications predicted by Pindel.
inv
the inversions predicted by Pindel.

Details

The predicted SVs could be further filtered by the number of reads supporting the occurence of a specific SV, and the predicted size of SVs to get more reliable SVs. See our paper for more details. The directory that specified by the parameter "dataDir" should only contain the predictions of Pindel. The deletions output files should be named using the suffix "_D", the duplications output files should be named using the suffix "_TD", and the inversions output files should be named using the suffix "_INV". See the example dataset for more details.

Examples

Run this code

    pindel <- readPindel(system.file("extdata/pindel",package="intansv"))
    str(pindel)

Run the code above in your browser using DataLab