the directory that contain the output files of CNVnator.
regSizeLowerCutoff
the minimum size for a structural
variation to be read.
regSizeUpperCutoff
the maximum size for a structural
variation to be read.
method
a tag to assign to the result of this function.
Value
A list with the following components:
del
the deletions predicted by CNVnator.
dup
the duplications predicted by CNVnator.
Details
The predicted SVs could be further filtered by the predicted
size of SVs to get more reliable SVs. See our paper for more details.
The directory that specified by the parameter "dataDir" should only
contain the predictions of CNVnator. See the example dataset
for more details.