readDelly: Read in the structural variations predicted by DELLY
Description
Reading the structural variations predicted by DELLY,
filtering low quality predictions and merging overlapping predictions.
Usage
readDelly(dataDir=".", regSizeLowerCutoff=100, regSizeUpperCutoff=1000000, readsSupport=3, method="DELLY", pass=TRUE, minMappingQuality=30)
Arguments
dataDir
a directory containing the prediction results of DELLY.
regSizeLowerCutoff
the minimum size for a structural
variation to be read.
regSizeUpperCutoff
the maximum size for a structural
variation to be read.
readsSupport
the minimum read pair support for a structural
variation to be read.
method
a tag to assign to the result of this function.
pass
set pass=TRUE to remove LowQual SVs reported by DELLY.
minMappingQuality
the minimum mapping quality for a SV to be read.
Value
A list with the following components:- del
- the deletions predicted by DELLY.
- dup
- the duplications predicted by DELLY.
- inv
- the inversions predicted by DELLY.
Details
The predicted SVs could be further filtered by the number of read pairs
supporting the occurence of a specific SV, and the predicted size of SVs
to get more reliable SVs. See our paper for more details.
The directory that specified by the parameter "dataDir" should only
contain the predictions of DELLY. See the example dataset for more details.
Examples
Run this code
delly <- readDelly(system.file("extdata/delly",package="intansv"))
str(delly)
Run the code above in your browser using DataLab